%define pypi_name networkx

%bcond_with docs

Name:		python-%{pypi_name}
Version:	3.5
Release:	%mkrel 1
Summary:	Python package for the study of complex networks
License:	BSD
Group:		Development/Python
Url:		https://networkx.org/
Source0:	%{pypi_source}
# For intersphinx
Source1:	https://numpy.org/neps/objects.inv#/objects-neps.inv
Source2:	https://matplotlib.org/stable/objects.inv#/objects-matplotlib.inv
Source3:	https://docs.scipy.org/doc/scipy/objects.inv#/objects-scipy.inv
Source4:	https://pandas.pydata.org/pandas-docs/stable/objects.inv#/objects-pandas.inv
Source5:	https://geopandas.org/en/stable/objects.inv#/objects-geopandas.inv
Source6:	https://sphinx-gallery.github.io/stable/objects.inv#/objects-sphinx-gallery.inv
Source7:	https://networkx.org/nx-guides/objects.inv#/objects-nx-guides.inv 
# The football example requires network access, so expect it to fail.
# The parallel betweenness example hangs when executed, possibly due to a
# function that cannot be pickled.  In any case, skip it.
Patch0:		0001-networkx-3.1-doc.patch
BuildArch:	noarch

BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(docutils)
BuildRequires:	xdg-utils

%if %{with docs}
# Documentation
BuildRequires:	python3dist(sphinx)
BuildRequires:	python3dist(sphinx-gallery)
BuildRequires:	python3dist(sphinx-rtd-theme)
BuildRequires:	python3dist(texext)
BuildRequires:	latex
BuildRequires:	zip
%endif

%description
NetworkX (NX) is a Python package for the creation, manipulation, and
study of the structure, dynamics, and functions of complex networks.

Features:
* Includes standard graph-theoretic and statistical physics functions
* Easy exchange of network algorithms between applications, disciplines,
  and platforms
* Includes many classic graphs and synthetic networks
* Nodes and edges can be "anything" (e.g. time-series, text, images,
  XML records)
* Exploits existing code from high-quality legacy software in C, C++,
  Fortran, etc.
* Open source (encourages community input)
* Unit-tested

%if %{with docs}
%package	doc
Summary:	Documentation for networkx
Group:		Documentation
Requires:	python3-%{pypi_name} >= %{version}-%{release}
Provides:	bundled(js-bootstrap)

%description	doc
Documentation for networkx.
%endif

%package -n	python3-%{pypi_name}
Summary:	Python 3 package for the study of complex networks
Group:		Development/Python

Recommends:	xdg-utils

%description -n	python3-networkx
NetworkX is a Python 3 package for the creation, manipulation, and
study of the structure, dynamics, and functions of complex networks.

%pyproject_extras_subpkg -n python3-networkx extra

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# Use local objects.inv for intersphinx
sed -e 's|\("https://numpy.org/neps/", \)None|\1"%{SOURCE1}"|' \
    -e 's|\("https://matplotlib.org/stable/", \)None|\1"%{SOURCE2}"|' \
    -e 's|\("https://docs.scipy.org/doc/scipy/", \)None|\1"%{SOURCE3}"|' \
    -e 's|\("https://pandas.pydata.org/pandas-docs/stable/", \)None|\1"%{SOURCE4}"|' \
    -e 's|\("https://geopandas.org/en/stable/", \)None|\1"%{SOURCE5}"|' \
    -e 's|\("https://sphinx-gallery.github.io/stable/", \)None|\1"%{SOURCE6}"|' \
    -e 's|\("https://networkx.org/nx-guides/", \)None|\1"%{SOURCE7}"|' \
    -i doc/conf.py

# Point to the local switcher instead of the inaccessible one on the web
sed -i 's,https://networkx.org/documentation/latest/,,' doc/conf.py

# Use a free font instead of a proprietary font
sed -i 's/Helvetica/sans-serif/' examples/drawing/plot_chess_masters.py

%generate_buildrequires
%pyproject_buildrequires


# Do not use env
for f in $(grep -FRl %{_bindir}/env .); do
  sed -e 's,%{_bindir}/env python[[:digit:]]*,%{python3},' \
      -e 's,%{_bindir}/env ,%{_bindir},' \
      -i.orig $f
  touch -r $f.orig $f
  rm $f.orig
done

# Use local objects.inv for intersphinx
sed -e 's|\("https://docs\.python\.org/3/": \)None|\1"%{_docdir}/python3-docs/html/objects.inv"|' \
    -e 's|\("https://numpy\.org/doc/stable/": \)None|\1"%{_docdir}/python3-numpy-doc/objects.inv"|' \
    -i doc/conf.py

%build
%pyproject_wheel

%if %{with docs}
# Build the documentation
PYTHONPATH=$PWD/build/lib make -C doc html
%endif
rst2html --no-datestamp README.rst README.html

%install
%pyproject_install
%pyproject_save_files networkx

# Repack uncompressed zip archives
for fil in $(find doc/build -name \*.zip); do
  mkdir zip
  cd zip
  unzip ../$fil
  zip -9r ../$fil .
  cd ..
  rm -fr zip
done

%check
%define enable_tests 0
%if %{enable_tests}
%pytest -v
%endif

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc README.html
%license LICENSE.txt

%if %{with docs}
%files doc
%doc doc/build/html/*
%endif


%changelog
* Wed Jun 04 2025 daviddavid <daviddavid> 3.5-1.mga10
+ Revision: 2188037
- new version: 3.5

* Sat Mar 01 2025 wally <wally> 3.4.2-2.mga10
+ Revision: 2155357
- rebuild for python3.13

* Tue Oct 29 2024 papoteur <papoteur> 3.4.2-1.mga10
+ Revision: 2111686
- new version 3.4.2
- use pyproject BR and remove requirements, including matlpotlib

* Tue Aug 06 2024 daviddavid <daviddavid> 3.3-1.mga10
+ Revision: 2083714
- new version: 3.3
- enable extra sub-pkg

* Wed Dec 27 2023 papoteur <papoteur> 3.2.1-2.mga10
+ Revision: 2022139
- rebuild for python 3.12
+ daviddavid <daviddavid>
- new version: 3.2.1

* Mon Oct 09 2023 papoteur <papoteur> 3.1-1.mga10
+ Revision: 1993830
- new 3.1

* Sun Dec 18 2022 daviddavid <daviddavid> 2.8.8-1.mga9
+ Revision: 1924904
- new version: 2.8.8

* Sun Nov 20 2022 daviddavid <daviddavid> 2.8.7-1.mga9
+ Revision: 1909556
- new version: 2.8.7

* Thu Nov 03 2022 papoteur <papoteur> 2.8.6-2.mga9
+ Revision: 1902060
- rebuild for fastjsonschema dependency

* Tue Sep 06 2022 papoteur <papoteur> 2.8.6-1.mga9
+ Revision: 1884503
- new 2.8.6

* Tue Aug 23 2022 papoteur <papoteur> 2.8.5-1.mga9
+ Revision: 1879747
- new 2.8.5

* Wed Apr 06 2022 umeabot <umeabot> 2.7-2.mga9
+ Revision: 1846187
- Mageia 9 Mass Rebuild

* Thu Mar 03 2022 mrambo3501 <mrambo3501> 2.7-1.mga9
+ Revision: 1788069
- version 2.7
- rediff Patch0
- delete Patch1 applied upstream

* Thu Mar 03 2022 mrambo3501 <mrambo3501> 2.5.1-2.mga9
+ Revision: 1788065
- build without docs for now
+ tv <tv>
- Rebuild for python-3.10

* Wed Apr 07 2021 daviddavid <daviddavid> 2.5.1-1.mga9
+ Revision: 1713955
- new version: 2.5.1

* Thu Mar 25 2021 guillomovitch <guillomovitch> 2.5-4.mga9
+ Revision: 1710119
- rebuild for python 3.9

* Tue Mar 23 2021 daviddavid <daviddavid> 2.5-3.mga9
+ Revision: 1708067
- rebuild for python 3.9

* Fri Oct 30 2020 joequant <joequant> 2.5-2.mga8
+ Revision: 1640633
- bump build

* Tue Aug 25 2020 daviddavid <daviddavid> 2.5-1.mga8
+ Revision: 1618841
- new version: 2.5
- all patches except -doc have been upstreamed; drop them

* Tue Jul 28 2020 daviddavid <daviddavid> 2.4-1.mga8
+ Revision: 1609382
- new version: 2.4

* Wed Jul 22 2020 ovitters <ovitters> 2.3-3.mga8
+ Revision: 1608090
- do not fail build if there is no /tmp/sphinx-err* to cat
- rebuild for get rid of pythonegg requires

* Sun Feb 16 2020 umeabot <umeabot> 2.3-2.mga8
+ Revision: 1533725
- Mageia 8 Mass Rebuild

* Tue Sep 24 2019 tv <tv> 2.3-1.mga8
+ Revision: 1445428
- disable testsuite for now
- BR zip
- display errors on failure
- fix building docs
- use %%autosetup
+ shlomif <shlomif>
- New version 2.3

* Wed Jan 09 2019 shlomif <shlomif> 1.11-5.mga7
+ Revision: 1353489
- Rebuild for python3 3.7

* Thu Sep 20 2018 umeabot <umeabot> 1.11-4.mga7
+ Revision: 1289481
- Mageia 7 Mass Rebuild

* Sat Aug 05 2017 pterjan <pterjan> 1.11-3.mga7
+ Revision: 1135517
- Rebuild for python 3.6

* Thu May 05 2016 philippem <philippem> 1.11-2.mga6
+ Revision: 1009629
- fix sphinx build

* Sun Jan 31 2016 daviddavid <daviddavid> 1.11-1.mga6
+ Revision: 929353
- new version: 1.11
- remove numpy patch

* Wed Dec 02 2015 daviddavid <daviddavid> 1.10-1.mga6
+ Revision: 907787
- new version: 1.10
- update URLs
- add -numpy patch from Fedora to fix test failure

* Thu Oct 08 2015 daviddavid <daviddavid> 1.9.1-2.mga6
+ Revision: 887341
- rebuild for python 3.5
- use new python macros

* Thu Jul 16 2015 daviddavid <daviddavid> 1.9.1-1.mga6
+ Revision: 854605
- new version: 1.9.1
- update new upstream URL
- add some upstream files to avoid downloading the doc files while building
- update BuildRequires and Requires list from main and python3 packages
- add some BuildRequires from doc subpackage on sphinx, sphinx_rtd_theme and numpydoc
- fix Group
- fix duplicate files on html doc
- update file list

* Wed Oct 15 2014 umeabot <umeabot> 1.8.1-7.mga5
+ Revision: 743524
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.8.1-6.mga5
+ Revision: 729148
- rebuild for missing pythoneggs deps
- s/uggests:/Recommends:/
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 1.8.1-4.mga5
+ Revision: 628843
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 1.8.1-3.mga4
+ Revision: 543868
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.8.1-2.mga4
+ Revision: 498964
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Sep 09 2013 philippem <philippem> 1.8.1-1.mga4
+ Revision: 476777
- Update to 1.8.1, add Python 3

* Sun Jan 13 2013 umeabot <umeabot> 1.7-3.mga3
+ Revision: 379160
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 1.7-2.mga3
+ Revision: 324753
- rebuild for Mga3 Beta1

* Sat Aug 25 2012 kamil <kamil> 1.7-1.mga3
+ Revision: 283806
- new version 1.7

* Wed Jul 04 2012 kamil <kamil> 1.6-1.mga3
+ Revision: 267115
- adapt .spec for Mageia
- imported package python-networkx


* Tue Nov 22 2011 Lev Givon <lev@mandriva.org> 1.6-1mdv2012.0
+ Revision: 732412
- Update to 1.6.

* Fri Jun 10 2011 Lev Givon <lev@mandriva.org> 1.5-1
+ Revision: 684190
- Update to 1.5.

* Tue Jan 25 2011 Lev Givon <lev@mandriva.org> 1.4-1
+ Revision: 632565
- Update to 1.4.

* Sun Nov 21 2010 Funda Wang <fwang@mandriva.org> 1.3-2mdv2011.0
+ Revision: 599414
- rebuild for p2.7

* Sun Aug 29 2010 Lev Givon <lev@mandriva.org> 1.3-1mdv2011.0
+ Revision: 574222
- Update to 1.3.

* Fri Aug 06 2010 Lev Givon <lev@mandriva.org> 1.2-1mdv2011.0
+ Revision: 566765
- Update to 1.2.

* Thu Apr 22 2010 Lev Givon <lev@mandriva.org> 1.1-1mdv2010.1
+ Revision: 537984
- Update to 1.1.

* Tue Jan 19 2010 Lev Givon <lev@mandriva.org> 1.0.1-1mdv2010.1
+ Revision: 493748
- Update to 1.0.1.

* Tue Sep 15 2009 Thierry Vignaud <tv@mandriva.org> 0.99-3mdv2010.0
+ Revision: 442320
- rebuild

* Wed Dec 31 2008 Adam Williamson <awilliamson@mandriva.org> 0.99-2mdv2009.1
+ Revision: 321621
- rebuild with python 2.6
- do a proper file list, clean up docs
- clean up python requires

* Sun Dec 14 2008 Lev Givon <lev@mandriva.org> 0.99-1mdv2009.1
+ Revision: 314213
- Update to 0.99.

* Mon Jul 07 2008 Lev Givon <lev@mandriva.org> 0.36-1mdv2009.0
+ Revision: 232509
- import python-networkx

